Volmdlr
=======

A python VOLume MoDeLeR computations-oriented including FreeCAD exports

.. image:: https://raw.githubusercontent.com/Dessia-tech/volmdlr/master/doc/source/images/casing.jpg

Installing
----------

.. code::

  pip(3) install volmdlr

Documentation
-------------
https://volmdlr.readthedocs.io/en/latest/
